﻿//
// Copyright (c) 2009-2015, MindFusion LLC - Bulgaria.
//
using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using MindFusion.Scheduling;
using System.Drawing;
using MindFusion.Scheduling.WebForms;

namespace MindFusion.Scheduling.Samples.CS.Customization
{
	public partial class _Default : System.Web.UI.Page
	{
		protected void Page_Load(object sender, EventArgs e)
		{
			CustomizePlanner();
			if (!IsPostBack)
			{
				CreateAppointments();
				Calendar1.ItemSelection.Add(Calendar1.Schedule.Items[new Random().Next(0, 14)]);
			}
		}

		private void CustomizePlanner()
		{
            #region Single month style
            MonthSettings msettings = Calendar1.MonthSettings;

            //Calendar
            msettings.Style.Borders.AllColor = Color.MidnightBlue;
            msettings.Style.Borders.AllWidth = new Unit(1, UnitType.Pixel);
            msettings.Style.Borders.AllStyle = BorderStyle.Solid;

            //Main header
            msettings.MainHeaderStyle.Brush.Color = Color.FromArgb(21, 53, 100); ;
            msettings.MainHeaderStyle.Brush.Image = "none";
            msettings.MainHeaderStyle.TextColor = Color.White;
            msettings.MainHeaderStyle.Borders.BottomStyle = BorderStyle.Outset;
            msettings.MainHeaderStyle.Borders.BottomColor = Color.White;

            //Navigation buttons
            msettings.ButtonStyle.Brush.Color = Color.FromArgb(27, 66, 124);
            msettings.ButtonStyle.Brush.Image = "none";
            msettings.ButtonStyle.Size.Height = 20;
            msettings.ButtonStyle.Size.Width = 20;

            //Day names header
            msettings.DayOfWeekFormat = DayOfWeekFormat.Full;
            msettings.DayNamesHeaderStyle.Brush.Color = Color.FromArgb(27, 66, 124);
            msettings.DayNamesHeaderStyle.TextColor = Color.White;
            msettings.DayNamesHeaderStyle.Borders.BottomColor = Color.White;
            msettings.DayNamesHeaderStyle.Borders.BottomStyle = BorderStyle.Inset;
            msettings.DayNamesHeaderStyle.Borders.TopStyle = BorderStyle.None;
            msettings.DayNamesHeaderStyle.Borders.LeftStyle = BorderStyle.None;

            //Week numbers header
            msettings.WeekNumbersHeaderStyle.Brush.Color = Color.FromArgb(27, 66, 124);
            msettings.WeekNumbersHeaderStyle.TextColor = Color.White;
            msettings.WeekNumbersHeaderStyle.Borders.AllStyle = BorderStyle.None;

            //Day cells
            msettings.DaySettings.HeaderStyle.Brush.Color = Color.FromArgb(82, 136, 219);
            msettings.DaySettings.HeaderStyle.Brush.Image = "none";
            msettings.DaySettings.HeaderStyle.TextColor = Color.White;

            msettings.DaySettings.Style.Brush.Color = Color.White;
            msettings.DaySettings.Style.Borders.LeftStyle = BorderStyle.Solid;
            msettings.DaySettings.Style.Borders.LeftColor = Color.FromArgb(145, 180, 232);
            msettings.DaySettings.Style.Borders.LeftWidth = new Unit(1, UnitType.Pixel);

            //Padding day cells
            msettings.PaddingDaysHeaderStyle.Brush.Color = Color.FromArgb(145, 180, 232);
            msettings.PaddingDaysHeaderStyle.Brush.Image = "none";
            msettings.PaddingDaysHeaderStyle.TextColor = Color.White;
            msettings.PaddingDaysHeaderStyle.TextAlignment = TextAlignment.MiddleRight;

            msettings.PaddingDaysStyle.Brush.Color = Color.FromArgb(204, 220, 244);
            #endregion

            #region List view style
            ListViewSettings lsettings = Calendar1.ListViewSettings;

            //Calendar
            lsettings.Style.Borders.AllColor = Color.MidnightBlue;
            lsettings.Style.Borders.AllWidth = new Unit(1, UnitType.Pixel);
            lsettings.Style.Borders.AllStyle = BorderStyle.Solid;

            //Main header
            lsettings.TitleFormat = "dddd, dd MMM";
            lsettings.MainHeaderStyle.Brush.Color = Color.FromArgb(21, 53, 100); ;
            lsettings.MainHeaderStyle.Brush.Image = "none";
            lsettings.MainHeaderStyle.TextColor = Color.White;
            lsettings.MainHeaderStyle.Borders.BottomStyle = BorderStyle.Outset;
            lsettings.MainHeaderStyle.Borders.BottomColor = Color.White;

            //Navigation buttons
            lsettings.ButtonStyle.Brush.Color = Color.FromArgb(27, 66, 124);
            lsettings.ButtonStyle.Brush.Image = "none";
            lsettings.ButtonStyle.Size.Height = 20;
            lsettings.ButtonStyle.Size.Width = 20;

            //Day cells
            lsettings.CellSettings.HeaderStyle.Brush.Color = Color.FromArgb(82, 136, 219);
            lsettings.CellSettings.HeaderStyle.Brush.Image = "none";
            lsettings.CellSettings.HeaderStyle.TextColor = Color.White;

            lsettings.CellSettings.Style.Brush.Color = Color.White;
            lsettings.CellSettings.Style.Borders.LeftStyle = BorderStyle.Solid;
            lsettings.CellSettings.Style.Borders.LeftColor = Color.FromArgb(145, 180, 232);
            lsettings.CellSettings.Style.Borders.LeftWidth = new Unit(1, UnitType.Pixel);

            //Fill colors
            lsettings.EvenWeeksFillColor.Color = Color.FromArgb(204, 220, 244);
            lsettings.OddWeeksFillColor.Color = Color.FromArgb(220, 231, 248);

            #endregion
		}

		private void CreateAppointments()
		{
			Random rnd = new Random(DateTime.Now.Millisecond);
			int year = DateTime.Today.Year;
			int month = DateTime.Today.Month;
			int maxDaysInMonth = DateTime.DaysInMonth(year, month);
			for (int i = 0; i < 15; )
			{
				Appointment app = new Appointment();
				app.StartTime = new DateTime(year, month, rnd.Next(1, maxDaysInMonth));
				app.EndTime = app.StartTime.AddDays(rnd.Next(1, 5));
				app.HeaderText = "sample item " + (++i);
				Calendar1.Schedule.Items.Add(app);
			}

		}

		protected void viewList_SelectedIndexChanged(object sender, EventArgs e)
		{
			var ddl = sender as DropDownList;
			if (ddl.SelectedIndex == 0)
				Calendar1.CurrentView = CalendarView.SingleMonth;
			else if (ddl.SelectedIndex == 1)
				Calendar1.CurrentView = CalendarView.List;
		}
	}
}
